Coverage for pages.migrations.0001_initial

# Coverage for pages.migrations.0001_initial : 36%

## 22 statements 8 run 0 excluded 14 missing

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 | # -*- coding: utf-8 -*- from south.db import db from django.db import models from pages.models import * class Migration: def forwards(self, orm): # Adding model 'Page' db.create_table('pages_page', ( ('id', orm['pages.Page:id']), ('author', orm['pages.Page:author']), ('parent', orm['pages.Page:parent']), ('creation_date', orm['pages.Page:creation_date']), ('publication_date', orm['pages.Page:publication_date']), ('publication_end_date', orm['pages.Page:publication_end_date']), ('last_modification_date', orm['pages.Page:last_modification_date']), ('status', orm['pages.Page:status']), ('template', orm['pages.Page:template']), ('delegate_to', orm['pages.Page:delegate_to']), ('redirect_to_url', orm['pages.Page:redirect_to_url']), ('redirect_to', orm['pages.Page:redirect_to']), ('tags', orm['pages.Page:tags']), ('lft', orm['pages.Page:lft']), ('rght', orm['pages.Page:rght']), ('tree_id', orm['pages.Page:tree_id']), ('level', orm['pages.Page:level']), )) db.send_create_signal('pages', ['Page']) # Adding model 'Content' db.create_table('pages_content', ( ('id', orm['pages.Content:id']), ('language', orm['pages.Content:language']), ('body', orm['pages.Content:body']), ('type', orm['pages.Content:type']), ('page', orm['pages.Content:page']), ('creation_date', orm['pages.Content:creation_date']), )) db.send_create_signal('pages', ['Content']) # Adding model 'PageAlias' db.create_table('pages_pagealias', ( ('id', orm['pages.PageAlias:id']), ('page', orm['pages.PageAlias:page']), ('url', orm['pages.PageAlias:url']), )) db.send_create_signal('pages', ['PageAlias']) # Adding model 'PagePermission' db.create_table('pages_pagepermission', ( ('id', orm['pages.PagePermission:id']), ('page', orm['pages.PagePermission:page']), ('user', orm['pages.PagePermission:user']), ('type', orm['pages.PagePermission:type']), )) db.send_create_signal('pages', ['PagePermission']) # Adding ManyToManyField 'Page.sites' db.create_table('pages_page_sites', ( ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)), ('page', models.ForeignKey(orm.Page, null=False)), ('site', models.ForeignKey(orm['sites.Site'], null=False)) )) def backwards(self, orm): # Deleting model 'Page' db.delete_table('pages_page') # Deleting model 'Content' db.delete_table('pages_content') # Deleting model 'PageAlias' db.delete_table('pages_pagealias') # Deleting model 'PagePermission' db.delete_table('pages_pagepermission') # Dropping ManyToManyField 'Page.sites' db.delete_table('pages_page_sites') models = { 'auth.group': { 'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}), 'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}), 'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'blank': 'True'}) }, 'auth.permission': { 'Meta': {'unique_together': "(('content_type', 'codename'),)"}, 'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}), 'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}), 'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}), 'name': ('django.db.models.fields.CharField', [], {'max_length': '50'}) }, 'auth.user': { 'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}), 'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}), 'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}), 'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'blank': 'True'}), 'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}), 'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True', 'blank': 'True'}), 'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}), 'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False', 'blank': 'True'}), 'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}), 'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}), 'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}), 'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'blank': 'True'}), 'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'}) }, 'contenttypes.contenttype': { 'Meta': {'unique_together': "(('app_label', 'model'),)", 'db_table': "'django_content_type'"}, 'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}), 'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}), 'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}), 'name': ('django.db.models.fields.CharField', [], {'max_length': '100'}) }, 'pages.content': { 'body': ('django.db.models.fields.TextField', [], {}), 'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}), 'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}), 'language': ('django.db.models.fields.CharField', [], {'max_length': '5'}), 'page': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['pages.Page']"}), 'type': ('django.db.models.fields.CharField', [], {'max_length': '100'}) }, 'pages.page': { 'author': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"}), 'creation_date': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}), 'delegate_to': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}), 'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}), 'last_modification_date': ('django.db.models.fields.DateTimeField', [], {}), 'level': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}), 'lft': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}), 'parent': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'children'", 'null': 'True', 'to': "orm['pages.Page']"}), 'publication_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}), 'publication_end_date': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}), 'redirect_to': ('django.db.models.fields.related.ForeignKey', [], {'blank': 'True', 'related_name': "'redirected_pages'", 'null': 'True', 'to': "orm['pages.Page']"}), 'redirect_to_url': ('django.db.models.fields.CharField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}), 'rght': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}), 'sites': ('django.db.models.fields.related.ManyToManyField', [], {'default': '[1]', 'to': "orm['sites.Site']"}), 'status': ('django.db.models.fields.IntegerField', [], {'default': '0'}), 'tags': ('tagging.fields.TagField', [], {'null': 'True'}), 'template': ('django.db.models.fields.CharField', [], {'max_length': '100', 'null': 'True', 'blank': 'True'}), 'tree_id': ('django.db.models.fields.PositiveIntegerField', [], {'db_index': 'True'}) }, 'pages.pagealias': { 'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}), 'page': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['pages.Page']", 'null': 'True', 'blank': 'True'}), 'url': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '255'}) }, 'pages.pagepermission': { 'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}), 'page': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['pages.Page']", 'null': 'True', 'blank': 'True'}), 'type': ('django.db.models.fields.IntegerField', [], {'default': '0'}), 'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"}) }, 'sites.site': { 'Meta': {'db_table': "'django_site'"}, 'domain': ('django.db.models.fields.CharField', [], {'max_length': '100'}), 'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}), 'name': ('django.db.models.fields.CharField', [], {'max_length': '50'}) } } complete_apps = ['pages']